California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 7, 2006, GENERAL
13 Measures
PROP 1A - SCA 7 (RESOLUTION 49, 2006). TORLAKSON. TRANSPORTATION INVESTMENT FUND.
PROP 1B - SB 1266 (CHAPTER 25, 2006). PERATA. HIGHWAY SAFETY, TRAFFIC REDUCTION, AIR QUALITY, PORT SECURITY BOND ACT
PROP 1C - SB 1689 (CHAPTER 25, 2006). PERATA. HOUSING AND EMERGENCY SHELTER TRUST FUND ACT OF 2006.
PROP 1D - AB 127 (CHAPTER 35, 2006). NUNEZ. EDUCATION FACILITIES: KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2006.
PROP 1E - AB 140 (CHAPTER 33, 2006). NUNEZ. DISASTER PREPAREDNESS AND FLOOD PREVENTION BOND ACT OF 2006.
PROP 83 - SEX OFFENDERS. SEXUALLY VIOLENT PREDATORS. PUNISHMENT, RESIDENCE RESTRICTIONS AND MONITORING. INITIATIVE STATUTE.
PROP 84 - WATER QUALITY, SAFETY AND SUPPLY. FLOOD CONTROL. NATURAL RESOURCE PROTECTION. PARK IMPROVEMENTS. BONDS. INITIATIVE STATUTE.
PROP 85 - WAITING PERIOD AND PARENTAL NOTIFICATION BEFORE TERMINATION OF MINOR'S PREGNANCY. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 86 - TAX ON CIGARETTES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 87 - ALTERNATIVE ENERGY. RESEARCH, PRODUCTION, INCENTIVES. TAX ON CALIFORNIA OIL. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 88 - EDUCATION FUNDING. REAL PROPERTY PARCEL TAX. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 89 - POLITICAL CAMPAIGNS. PUBLIC FINANCING. CORPORATE TAX INCREASE. CONTRIBUTION AND EXPENDITURE LIMITS. INITIATIVE STATUTE.
PROP 90 - GOVERNMENT ACQUISITION, REGULATION OF PRIVATE PROPERTY. INITIATIVE CONSTITUTIONAL AMENDMENT.
JUNE 6, 2006, PRIMARY
2 Measures
PROP 81 - SB 1161 (CHAPTER 698, 2004). ALPERT. CALIFORNIA READING AND LITERACY IMPROVEMENT AND PUBLIC LIBRARY CONSTRUCTION AND RENOVATION BOND ACT OF 2006.
PROP 82 - PUBLIC PRESCHOOL EDUCATION. TAX INCREASE ON INCOMES OVER $400,000 FOR INDIVIDUALS; $800,000 FOR COUPLES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
NOVEMBER 8, 2005, SPECIAL ELECTION
8 Measures
PROP 73 - TERMINATION OF MINOR'S PREGNANCY. WAITING PERIOD AND PARENTAL NOTIFICATION. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 74 - PUBLIC SCHOOL TEACHERS. WAITING PERIOD FOR PERMANENT STATUS. DISMISSAL. INITIATIVE STATUTE.
PROP 75 - PUBLIC EMPLOYEE UNION DUES. REQUIRED EMPLOYEE CONSENT FOR POLITICAL CONTRIBUTIONS. INITIATIVE STATUTE.
PROP 76 - SCHOOL FUNDING. STATE SPENDING. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 77 - REAPPORTIONMENT. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 78 - PRESCRIPTION DRUGS. DISCOUNTS. INITIATIVE STATUTE.
PROP 79 - PRESCRIPTION DRUG DISCOUNTS. STATE-NEGOTIATED REBATES. INITIATIVE STATUTE.
PROP 80 - ELECTRIC SERVICE PROVIDERS. REGULATION. INITIATIVE STATUTE.